@@ -13,7 +13,7 @@ use Pandoc::Walker;
 use Pandoc::Elements qw(Image Str);
 
 use parent 'Exporter';
-our @EXPORT = qw(pandoc_filter pandoc_filter_document pandoc_walk build_image stringify);
+our @EXPORT = qw(pandoc_filter pandoc_filter_document pandoc_walk stringify);
 
 # FUNCTIONS
 
@@ -24,6 +24,7 @@ sub stringify {
     $_[0]->string;
 }
 
+# TODO: deprecate this function
 sub pandoc_walk(@) {    ## no critic
     my $filter = Pandoc::Filter->new(@_);
     my $ast    = Pandoc::Elements::pandoc_json(<STDIN>);
@@ -60,35 +61,6 @@ sub pandoc_filter_document($) {    ## no critic
     say $doc->to_json;
 }
 
-# build_image( $element [, $filename ] )
-#
-# Maps an element to an L<Image|Pandoc::Elements/Image> element with attributes
-# from the given element. The attribute C<caption>, if available, is transformed
-# into image caption. This utility function is useful for filters that transform
-# content to images. See graphviz, tikz, lilypond and similar filters in the
-# L<examples|https://metacpan.org/pod/distribution/Pandoc-Elements/examples/>.
-#
-# This function will be (re)moved during further refactoring
-
-sub build_image {
-    my $e = shift;
-    my $filename = shift // '';
-
-    my $img = Image [$e->id, $e->classes, []], [], [$filename, ''];
-    my $keyvals = $e->keyvals;
-
-    my $caption = $keyvals->get('caption');
-    if (defined $caption) {
-        push @{$img->content}, Str($caption);
-        $img->target->[1] = 'fig:';
-        $keyvals->remove('caption');
-    }
-    $img->keyvals($keyvals);
-
-    return $img;
-}
-
-
 # METHODS
 
 sub new {
@@ -102,6 +74,7 @@ sub new {
     }, $class;
 }
 
+# TODO: remove this method, only used on Pandoc::Filter::Lazy and pandocwalk
 sub error {
     $_[0]->{error};
 }
@@ -205,19 +178,10 @@ Document by default (if the AST is a Document root).
 
 Return a code reference to call all actions.
 
-=head2 size
-
-Return the number of actions in this filter.
-
 =head1 FUNCTIONS
 
 The following functions are exported by default.
 
-=head2 pandoc_walk( @actions | %actions )
-
-Read a single line of JSON from STDIN and walk down the document content AST
-(without metadata elements).  Implicitly sets binmode UTF-8 for STDOUT.
-
 =head2 pandoc_filter( @actions | %actions )
 
 Read a single line of JSON from STDIN, apply actions on the document content
@@ -225,18 +189,23 @@ and print the resulting AST as single line of JSON. L<Pandoc::Filter::Usage>
 is used to print filter documentation if called with command line argument
 C<--help>, C<-h>, or C<-?>.
 
-=head2 pandoc_filter_document( $filter )
+=head1 FILTER MODULES
 
-Same as C<pandoc_filter> but applies filter to the whole Document.
+=over
+
+=item L<Pandoc::Filter::HeaderIdentifiers>
+
+=item L<Pandoc::Filter::Multifilter>
+
+=item L<Pandoc::Filter::ImagesFromCode>
+
+=back
 
 =head1 SEE ALSO
 
 This module is a port of L<pandocfilters|https://github.com/jgm/pandocfilters>
 from Python to modern Perl.  
 
-Script L<pandocwalk>, installed with this module, facilitates execution of
-C<pandoc_walk> to traverse a document from command line.
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2014- Jakob Voß
